@@ -349,7 +349,7 @@ def track_mslp(input, outdirectory, NH=True, netcdf=True):
 
         # select year from data
         year_file = 'tempyear.nc'
-        cdo.selyear(year, input=tempname, output="indat/"+year_file)
+        cdo.selyear(year, input="indat/"+filled, output="indat/"+year_file)
 
         # get number of timesteps and number of chunks for tracking
         data = cmip6_indat("indat/"+year_file)
@@ -527,7 +527,7 @@ def track_uv_vor850(infile, outdirectory, infile2='none', NH=True, netcdf=True):
 
         # select year from data
         year_file = 'tempyear.nc'
-        cdo.selyear(year, input=tempname, output="indat/"+year_file)
+        cdo.selyear(year, input="indat/"+filled, output="indat/"+year_file)
 
         # get number of timesteps and number of chunks for tracking
         data = cmip6_indat("indat/"+year_file)
